@@ -41,7 +41,10 @@ use crate::{
         AutoArchiveDuration, NewsThread, PrivateThread, PublicThread, ThreadMember, ThreadMetadata,
     },
     datetime::Timestamp,
-    id::{ChannelId, GuildId, MessageId, UserId},
+    id::{
+        marker::{ChannelMarker, GuildMarker, MessageMarker, UserMarker},
+        Id,
+    },
 };
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
@@ -78,7 +81,7 @@ pub enum Channel {
 
 impl Channel {
     /// Return the ID of the inner channel.
-    pub const fn id(&self) -> ChannelId {
+    pub const fn id(&self) -> Id<ChannelMarker> {
         match self {
             Self::Group(group) => group.id,
             Self::Guild(guild_channel) => guild_channel.id(),
@@ -123,7 +126,7 @@ pub enum GuildChannel {
 
 impl GuildChannel {
     /// Return the guild ID of the inner guild channel.
-    pub const fn guild_id(&self) -> Option<GuildId> {
+    pub const fn guild_id(&self) -> Option<Id<GuildMarker>> {
         match self {
             Self::Category(category) => category.guild_id,
             Self::NewsThread(thread) => thread.guild_id,
@@ -136,7 +139,7 @@ impl GuildChannel {
     }
 
     /// Return the ID of the inner guild channel.
-    pub const fn id(&self) -> ChannelId {
+    pub const fn id(&self) -> Id<ChannelMarker> {
         match self {
             Self::Category(category) => category.id,
             Self::NewsThread(thread) => thread.id,
@@ -230,15 +233,15 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
         let mut id = None;
         let mut invitable: Option<Option<bool>> = None;
         let mut kind = None;
-        let mut last_message_id: Option<Option<MessageId>> = None;
+        let mut last_message_id: Option<Option<Id<MessageMarker>>> = None;
         let mut last_pin_timestamp: Option<Option<Timestamp>> = None;
         let mut member: Option<Option<ThreadMember>> = None;
         let mut member_count: Option<u8> = None;
         let mut message_count: Option<u8> = None;
         let mut name = None;
         let mut nsfw = None;
-        let mut owner_id: Option<Option<UserId>> = None;
-        let mut parent_id: Option<Option<ChannelId>> = None;
+        let mut owner_id: Option<Option<Id<UserMarker>>> = None;
+        let mut parent_id: Option<Option<Id<ChannelMarker>>> = None;
         let mut permission_overwrites = None;
         let mut position = None;
         let mut rate_limit_per_user = None;
@@ -690,27 +693,27 @@ mod tests {
         channel::permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
         datetime::Timestamp,
         guild::Permissions,
-        id::{ChannelId, GuildId, MessageId, UserId},
+        id::{marker::ChannelMarker, Id},
     };
 
     fn group() -> Group {
         Group {
             application_id: None,
             icon: None,
-            id: ChannelId::new(123).expect("non zero"),
+            id: Id::new(123),
             kind: ChannelType::Group,
             last_message_id: None,
             last_pin_timestamp: None,
             name: Some("a group".to_owned()),
-            owner_id: UserId::new(456).expect("non zero"),
+            owner_id: Id::new(456),
             recipients: Vec::new(),
         }
     }
 
     fn guild_category() -> CategoryChannel {
         CategoryChannel {
-            guild_id: Some(GuildId::new(321).expect("non zero")),
-            id: ChannelId::new(123).expect("non zero"),
+            guild_id: Some(Id::new(321)),
+            id: Id::new(123),
             kind: ChannelType::GuildCategory,
             name: "category".to_owned(),
             permission_overwrites: Vec::new(),
@@ -720,8 +723,8 @@ mod tests {
 
     fn guild_text() -> TextChannel {
         TextChannel {
-            guild_id: Some(GuildId::new(321).expect("non zero")),
-            id: ChannelId::new(456).expect("non zero"),
+            guild_id: Some(Id::new(321)),
+            id: Id::new(456),
             kind: ChannelType::GuildText,
             last_message_id: None,
             last_pin_timestamp: None,
@@ -738,8 +741,8 @@ mod tests {
     fn guild_voice() -> VoiceChannel {
         VoiceChannel {
             bitrate: 1000,
-            guild_id: Some(GuildId::new(321).expect("non zero")),
-            id: ChannelId::new(789).expect("non zero"),
+            guild_id: Some(Id::new(321)),
+            id: Id::new(789),
             kind: ChannelType::GuildVoice,
             name: "voice".to_owned(),
             permission_overwrites: Vec::new(),
@@ -754,8 +757,8 @@ mod tests {
     fn guild_stage() -> VoiceChannel {
         VoiceChannel {
             bitrate: 1000,
-            guild_id: Some(GuildId::new(321).expect("non zero")),
-            id: ChannelId::new(789).expect("non zero"),
+            guild_id: Some(Id::new(321)),
+            id: Id::new(789),
             kind: ChannelType::GuildStageVoice,
             name: "stage".to_owned(),
             permission_overwrites: Vec::new(),
@@ -767,9 +770,9 @@ mod tests {
         }
     }
 
-    fn private() -> PrivateChannel {
+    const fn private() -> PrivateChannel {
         PrivateChannel {
-            id: ChannelId::new(234).expect("non zero"),
+            id: Id::new(234),
             last_message_id: None,
             last_pin_timestamp: None,
             kind: ChannelType::Private,
@@ -779,30 +782,24 @@ mod tests {
 
     #[test]
     fn test_channel_helpers() {
-        assert_eq!(
-            Channel::Group(group()).id(),
-            ChannelId::new(123).expect("non zero")
-        );
+        assert_eq!(Channel::Group(group()).id(), Id::new(123));
         assert_eq!(
             Channel::Guild(GuildChannel::Category(guild_category())).id(),
-            ChannelId::new(123).expect("non zero")
+            Id::new(123)
         );
         assert_eq!(
             Channel::Guild(GuildChannel::Text(guild_text())).id(),
-            ChannelId::new(456).expect("non zero")
+            Id::new(456)
         );
         assert_eq!(
             Channel::Guild(GuildChannel::Voice(guild_voice())).id(),
-            ChannelId::new(789).expect("non zero")
+            Id::new(789)
         );
         assert_eq!(
             Channel::Guild(GuildChannel::Stage(guild_stage())).id(),
-            ChannelId::new(789).expect("non zero")
-        );
-        assert_eq!(
-            Channel::Private(private()).id(),
-            ChannelId::new(234).expect("non zero")
+            Id::new(789)
         );
+        assert_eq!(Channel::Private(private()).id(), Id::new(234));
     }
 
     #[test]
@@ -876,40 +873,28 @@ mod tests {
     fn test_guild_channel_guild_id() {
         assert_eq!(
             GuildChannel::Category(guild_category()).guild_id(),
-            Some(GuildId::new(321).expect("non zero"))
+            Some(Id::new(321))
         );
         assert_eq!(
             GuildChannel::Text(guild_text()).guild_id(),
-            Some(GuildId::new(321).expect("non zero"))
+            Some(Id::new(321))
         );
         assert_eq!(
             GuildChannel::Voice(guild_voice()).guild_id(),
-            Some(GuildId::new(321).expect("non zero"))
+            Some(Id::new(321))
         );
         assert_eq!(
             GuildChannel::Stage(guild_stage()).guild_id(),
-            Some(GuildId::new(321).expect("non zero"))
+            Some(Id::new(321))
         );
     }
 
     #[test]
     fn test_guild_channel_id() {
-        assert_eq!(
-            GuildChannel::Category(guild_category()).id(),
-            ChannelId::new(123).expect("non zero")
-        );
-        assert_eq!(
-            GuildChannel::Text(guild_text()).id(),
-            ChannelId::new(456).expect("non zero")
-        );
-        assert_eq!(
-            GuildChannel::Voice(guild_voice()).id(),
-            ChannelId::new(789).expect("non zero")
-        );
-        assert_eq!(
-            GuildChannel::Stage(guild_stage()).id(),
-            ChannelId::new(789).expect("non zero")
-        );
+        assert_eq!(GuildChannel::Category(guild_category()).id(), Id::new(123));
+        assert_eq!(GuildChannel::Text(guild_text()).id(), Id::new(456));
+        assert_eq!(GuildChannel::Voice(guild_voice()).id(), Id::new(789));
+        assert_eq!(GuildChannel::Stage(guild_stage()).id(), Id::new(789));
     }
 
     #[test]
@@ -952,10 +937,10 @@ mod tests {
         });
 
         let value = GuildChannel::Text(TextChannel {
-            guild_id: Some(GuildId::new(1).expect("non zero")),
-            id: ChannelId::new(2).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(2),
             kind: ChannelType::GuildText,
-            last_message_id: Some(MessageId::new(3).expect("non zero")),
+            last_message_id: Some(Id::new(3)),
             last_pin_timestamp: None,
             name: "hey".to_owned(),
             nsfw: false,
@@ -972,8 +957,8 @@ mod tests {
     #[test]
     fn test_guild_category_channel_deserialization() {
         let value = GuildChannel::Category(CategoryChannel {
-            id: ChannelId::new(1).expect("non zero"),
-            guild_id: Some(GuildId::new(2).expect("non zero")),
+            id: Id::new(1),
+            guild_id: Some(Id::new(2)),
             kind: ChannelType::GuildCategory,
             name: "foo".to_owned(),
             permission_overwrites: Vec::new(),
@@ -988,7 +973,7 @@ mod tests {
                 "guild_id": Some("2"),
                 "name": "foo",
                 "nsfw": false,
-                "parent_id": None::<ChannelId>,
+                "parent_id": None::<Id<ChannelMarker>>,
                 "permission_overwrites": permission_overwrites,
                 "position": 3,
                 "type": 4,
@@ -1000,15 +985,15 @@ mod tests {
     #[test]
     fn test_guild_news_channel_deserialization() {
         let value = GuildChannel::Text(TextChannel {
-            id: ChannelId::new(1).expect("non zero"),
-            guild_id: Some(GuildId::new(2).expect("non zero")),
+            id: Id::new(1),
+            guild_id: Some(Id::new(2)),
             kind: ChannelType::GuildNews,
-            last_message_id: Some(MessageId::new(4).expect("non zero")),
+            last_message_id: Some(Id::new(4)),
             last_pin_timestamp: None,
             name: "news".to_owned(),
             nsfw: true,
             permission_overwrites: Vec::new(),
-            parent_id: Some(ChannelId::new(5).expect("non zero")),
+            parent_id: Some(Id::new(5)),
             position: 3,
             rate_limit_per_user: None,
             topic: Some("a news channel".to_owned()),
@@ -1036,8 +1021,8 @@ mod tests {
     #[test]
     fn test_guild_store_channel_deserialization() {
         let value = GuildChannel::Text(TextChannel {
-            id: ChannelId::new(1).expect("non zero"),
-            guild_id: Some(GuildId::new(2).expect("non zero")),
+            id: Id::new(1),
+            guild_id: Some(Id::new(2)),
             kind: ChannelType::GuildStore,
             last_message_id: None,
             last_pin_timestamp: None,
@@ -1074,23 +1059,23 @@ mod tests {
 
         let value = GuildChannel::NewsThread(NewsThread {
             default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
-            guild_id: Some(GuildId::new(1)).expect("non zero"),
-            id: ChannelId::new(6).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(6),
             kind: ChannelType::GuildNewsThread,
-            last_message_id: Some(MessageId::new(3)).expect("non zero"),
+            last_message_id: Some(Id::new(3)),
             member: Some(ThreadMember {
                 flags: 0_u64,
-                id: Some(ChannelId::new(4)).expect("non zero"),
+                id: Some(Id::new(4)),
                 join_timestamp: timestamp,
                 member: None,
                 presence: None,
-                user_id: Some(UserId::new(5)).expect("non zero"),
+                user_id: Some(Id::new(5)),
             }),
             member_count: 50_u8,
             message_count: 50_u8,
             name: "newsthread".into(),
-            owner_id: Some(UserId::new(5)).expect("non zero"),
-            parent_id: Some(ChannelId::new(2)).expect("non zero"),
+            owner_id: Some(Id::new(5)),
+            parent_id: Some(Id::new(2)),
             rate_limit_per_user: Some(1000_u64),
             thread_metadata: ThreadMetadata {
                 archived: false,
@@ -1140,23 +1125,23 @@ mod tests {
 
         let value = GuildChannel::PublicThread(PublicThread {
             default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
-            guild_id: Some(GuildId::new(1)).expect("non zero"),
-            id: ChannelId::new(6).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(6),
             kind: ChannelType::GuildPublicThread,
-            last_message_id: Some(MessageId::new(3)).expect("non zero"),
+            last_message_id: Some(Id::new(3)),
             member: Some(ThreadMember {
                 flags: 0_u64,
-                id: Some(ChannelId::new(4)).expect("non zero"),
+                id: Some(Id::new(4)),
                 join_timestamp: timestamp,
                 member: None,
                 presence: None,
-                user_id: Some(UserId::new(5)).expect("non zero"),
+                user_id: Some(Id::new(5)),
             }),
             member_count: 50_u8,
             message_count: 50_u8,
             name: "publicthread".into(),
-            owner_id: Some(UserId::new(5)).expect("non zero"),
-            parent_id: Some(ChannelId::new(2)).expect("non zero"),
+            owner_id: Some(Id::new(5)),
+            parent_id: Some(Id::new(2)),
             rate_limit_per_user: Some(1000_u64),
             thread_metadata: ThreadMetadata {
                 archived: false,
@@ -1207,28 +1192,28 @@ mod tests {
 
         let value = GuildChannel::PrivateThread(PrivateThread {
             default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
-            guild_id: Some(GuildId::new(1)).expect("non zero"),
-            id: ChannelId::new(6).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(6),
             invitable: Some(true),
             kind: ChannelType::GuildPrivateThread,
-            last_message_id: Some(MessageId::new(3)).expect("non zero"),
+            last_message_id: Some(Id::new(3)),
             member: Some(ThreadMember {
                 flags: 0_u64,
-                id: Some(ChannelId::new(4)).expect("non zero"),
+                id: Some(Id::new(4)),
                 join_timestamp: timestamp,
                 member: None,
                 presence: None,
-                user_id: Some(UserId::new(5)).expect("non zero"),
+                user_id: Some(Id::new(5)),
             }),
             member_count: 50_u8,
             message_count: 50_u8,
             name: "privatethread".into(),
-            owner_id: Some(UserId::new(5)).expect("non zero"),
-            parent_id: Some(ChannelId::new(2)).expect("non zero"),
+            owner_id: Some(Id::new(5)),
+            parent_id: Some(Id::new(2)),
             permission_overwrites: Vec::from([PermissionOverwrite {
                 allow: Permissions::empty(),
                 deny: Permissions::empty(),
-                kind: PermissionOverwriteType::Member(UserId::new(5).expect("non zero")),
+                kind: PermissionOverwriteType::Member(Id::new(5)),
             }]),
             rate_limit_per_user: Some(1000_u64),
             thread_metadata: ThreadMetadata {
