@@ -2,15 +2,17 @@ mod privacy_level;
 
 pub use self::privacy_level::PrivacyLevel;
 
-use crate::id::{ChannelId, GuildId, StageId};
+use crate::id::{
+    marker::{ChannelMarker, GuildMarker, StageMarker},
+    Id,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct StageInstance {
-    pub channel_id: ChannelId,
-    pub discoverable_disabled: bool,
-    pub guild_id: GuildId,
-    pub id: StageId,
+    pub channel_id: Id<ChannelMarker>,
+    pub guild_id: Id<GuildMarker>,
+    pub id: Id<StageMarker>,
     pub privacy_level: PrivacyLevel,
     pub topic: String,
 }
@@ -18,17 +20,16 @@ pub struct StageInstance {
 #[cfg(test)]
 mod test {
     use super::{PrivacyLevel, StageInstance};
-    use crate::id::{ChannelId, GuildId, StageId};
+    use crate::id::Id;
     use serde_test::Token;
 
     #[test]
     fn test_stage_instance() {
         let value = StageInstance {
-            channel_id: ChannelId::new(100).expect("non zero"),
-            discoverable_disabled: false,
-            guild_id: GuildId::new(200).expect("non zero"),
-            id: StageId::new(300).expect("non zero"),
-            privacy_level: PrivacyLevel::Public,
+            channel_id: Id::new(100),
+            guild_id: Id::new(200),
+            id: Id::new(300),
+            privacy_level: PrivacyLevel::GuildOnly,
             topic: "a topic".into(),
         };
 
@@ -37,21 +38,19 @@ mod test {
             &[
                 Token::Struct {
                     name: "StageInstance",
-                    len: 6,
+                    len: 5,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("100"),
-                Token::Str("discoverable_disabled"),
-                Token::Bool(false),
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("200"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "StageId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("300"),
                 Token::Str("privacy_level"),
-                Token::U8(1),
+                Token::U8(2),
                 Token::Str("topic"),
                 Token::Str("a topic"),
                 Token::StructEnd,
