@@ -1,7 +1,7 @@
-use crate::id::GuildId;
+use crate::id::{marker::GuildMarker, Id};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct GuildIntegrationsUpdate {
-    pub guild_id: GuildId,
+    pub guild_id: Id<GuildMarker>,
 }
