@@ -23,6 +23,7 @@ pub use self::{
 
 use crate::{
     channel::{GuildChannel, Webhook},
+    scheduled_event::GuildScheduledEvent,
     user::User,
 };
 use serde::{Deserialize, Serialize};
@@ -37,6 +38,8 @@ pub struct AuditLog {
     /// Paginated entries in a guild's audit log.
     #[serde(rename = "audit_log_entries")]
     pub entries: Vec<AuditLogEntry>,
+    /// Information about mentioned scheduled events.
+    pub guild_scheduled_events: Vec<GuildScheduledEvent>,
     /// Information about mentioned integrations.
     pub integrations: Vec<AuditLogGuildIntegration>,
     /// Information about mentioned threads.
@@ -58,7 +61,13 @@ mod tests {
     use static_assertions::{assert_fields, assert_impl_all};
     use std::{fmt::Debug, hash::Hash};
 
-    assert_fields!(AuditLog: entries, integrations, users, webhooks);
+    assert_fields!(
+        AuditLog: entries,
+        guild_scheduled_events,
+        integrations,
+        users,
+        webhooks
+    );
     assert_impl_all!(
         AuditLog: Clone,
         Debug,
@@ -80,6 +89,7 @@ mod tests {
     fn test_serde() {
         let value = AuditLog {
             entries: Vec::new(),
+            guild_scheduled_events: Vec::new(),
             integrations: Vec::new(),
             threads: Vec::new(),
             users: Vec::new(),
@@ -91,11 +101,14 @@ mod tests {
             &[
                 Token::Struct {
                     name: "AuditLog",
-                    len: 5,
+                    len: 6,
                 },
                 Token::Str("audit_log_entries"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
+                Token::Str("guild_scheduled_events"),
+                Token::Seq { len: Some(0) },
+                Token::SeqEnd,
                 Token::Str("integrations"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
