@@ -1,22 +1,27 @@
-use crate::{guild::VerificationLevel, id::GuildId, invite::WelcomeScreen};
+use crate::{
+    guild::VerificationLevel,
+    id::{marker::GuildMarker, Id},
+    invite::WelcomeScreen,
+    util::image_hash::ImageHash,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct InviteGuild {
     /// Hash of the banner image.
-    pub banner: Option<String>,
+    pub banner: Option<ImageHash>,
     /// Description used for guild discovery.
     pub description: Option<String>,
     /// List of features that the guild has had enabled.
     pub features: Vec<String>,
     /// Hash of the icon image.
-    pub icon: Option<String>,
+    pub icon: Option<ImageHash>,
     /// ID of the guild.
-    pub id: GuildId,
+    pub id: Id<GuildMarker>,
     /// Name of the guild.
     pub name: String,
     /// Hash of the splash image.
-    pub splash: Option<String>,
+    pub splash: Option<ImageHash>,
     /// Vanity code unique to the guild for invites.
     pub vanity_url_code: Option<String>,
     /// Account verification level required to participate.
@@ -27,39 +32,36 @@ pub struct InviteGuild {
 
 #[cfg(test)]
 mod tests {
-    use super::{GuildId, InviteGuild, VerificationLevel, WelcomeScreen};
-    use crate::{
-        id::{ChannelId, EmojiId},
-        invite::WelcomeScreenChannel,
-    };
+    use super::{InviteGuild, VerificationLevel, WelcomeScreen};
+    use crate::{id::Id, invite::WelcomeScreenChannel, test::image_hash};
     use serde_test::Token;
 
     #[test]
     #[allow(clippy::too_many_lines)]
     fn test_invite_guild() {
         let value = InviteGuild {
-            banner: Some("banner hash".to_owned()),
+            banner: Some(image_hash::BANNER),
             description: Some("a description".to_owned()),
             features: vec!["a feature".to_owned()],
-            icon: Some("icon hash".to_owned()),
-            id: GuildId::new(1).expect("non zero"),
+            icon: Some(image_hash::ICON),
+            id: Id::new(1),
             name: "guild name".to_owned(),
-            splash: Some("splash hash".to_owned()),
+            splash: Some(image_hash::SPLASH),
             vanity_url_code: Some("twilight".to_owned()),
             verification_level: VerificationLevel::Medium,
             welcome_screen: Some(WelcomeScreen {
                 description: Some("welcome description".to_owned()),
                 welcome_channels: vec![
                     WelcomeScreenChannel {
-                        channel_id: ChannelId::new(123).expect("non zero"),
+                        channel_id: Id::new(123),
                         description: "channel description".to_owned(),
                         emoji_id: None,
                         emoji_name: Some("\u{1f352}".to_owned()),
                     },
                     WelcomeScreenChannel {
-                        channel_id: ChannelId::new(456).expect("non zero"),
+                        channel_id: Id::new(456),
                         description: "custom description".to_owned(),
-                        emoji_id: Some(EmojiId::new(789).expect("non zero")),
+                        emoji_id: Some(Id::new(789)),
                         emoji_name: Some("custom_name".to_owned()),
                     },
                 ],
@@ -75,7 +77,7 @@ mod tests {
                 },
                 Token::Str("banner"),
                 Token::Some,
-                Token::Str("banner hash"),
+                Token::Str(image_hash::BANNER_INPUT),
                 Token::Str("description"),
                 Token::Some,
                 Token::Str("a description"),
@@ -85,15 +87,15 @@ mod tests {
                 Token::SeqEnd,
                 Token::Str("icon"),
                 Token::Some,
-                Token::Str("icon hash"),
+                Token::Str(image_hash::ICON_INPUT),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("guild name"),
                 Token::Str("splash"),
                 Token::Some,
-                Token::Str("splash hash"),
+                Token::Str(image_hash::SPLASH_INPUT),
                 Token::Str("vanity_url_code"),
                 Token::Some,
                 Token::Str("twilight"),
@@ -115,7 +117,7 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("123"),
                 Token::Str("description"),
                 Token::Str("channel description"),
@@ -130,13 +132,13 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("456"),
                 Token::Str("description"),
                 Token::Str("custom description"),
                 Token::Str("emoji_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "EmojiId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("789"),
                 Token::Str("emoji_name"),
                 Token::Some,
