@@ -48,7 +48,7 @@
 //! [github link]: https://github.com/twilight-rs/twilight
 //! [license badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=for-the-badge&logo=pastebin
 //! [license link]: https://github.com/twilight-rs/twilight/blob/main/LICENSE.md
-//! [rust badge]: https://img.shields.io/badge/rust-1.53+-93450a.svg?style=for-the-badge&logo=rust
+//! [rust badge]: https://img.shields.io/badge/rust-1.57+-93450a.svg?style=for-the-badge&logo=rust
 
 #![deny(
     clippy::all,
@@ -76,9 +76,13 @@ pub mod guild;
 pub mod id;
 pub mod invite;
 pub mod oauth;
+pub mod scheduled_event;
 pub mod template;
 pub mod user;
+pub mod util;
 pub mod voice;
 
-pub(crate) mod util;
 mod visitor;
+
+#[cfg(test)]
+mod test;
