@@ -6,7 +6,10 @@ pub use role::TemplateRole;
 
 use crate::{
     datetime::Timestamp,
-    id::{GuildId, UserId},
+    id::{
+        marker::{GuildMarker, UserMarker},
+        Id,
+    },
     user::User,
 };
 use serde::{Deserialize, Serialize};
@@ -18,13 +21,13 @@ pub struct Template {
     /// User object of who created this template.
     pub creator: User,
     /// ID of the user who created this template.
-    pub creator_id: UserId,
+    pub creator_id: Id<UserMarker>,
     pub description: Option<String>,
     /// Whether the template has unsynced changes.
     pub is_dirty: Option<bool>,
     pub name: String,
     pub serialized_source_guild: TemplateGuild,
-    pub source_guild_id: GuildId,
+    pub source_guild_id: Id<GuildMarker>,
     pub updated_at: Timestamp,
     pub usage_count: u64,
 }
@@ -42,7 +45,8 @@ mod tests {
             DefaultMessageNotificationLevel, ExplicitContentFilter, Permissions,
             SystemChannelFlags, VerificationLevel,
         },
-        id::{ChannelId, GuildId, RoleId, UserId},
+        id::Id,
+        test::image_hash,
         user::{User, UserFlags},
     };
     use serde_test::Token;
@@ -54,27 +58,28 @@ mod tests {
         let created_at = Timestamp::from_str("2021-04-07T14:55:37+00:00")?;
         let updated_at = Timestamp::from_str("2021-04-07T14:55:37+00:00")?;
 
-        let raw = r#"{
+        let raw = format!(
+            r#"{{
     "code": "code",
     "created_at": "2021-04-07T14:55:37+00:00",
-    "creator": {
+    "creator": {{
         "accent_color": null,
-        "avatar": "avatar",
-        "banner": "06c16474723fe537c283b8efa61a30c8",
+        "avatar": "{avatar}",
+        "banner": "{banner}",
         "discriminator": "1111",
         "id": "100",
         "public_flags": 0,
         "username": "username"
-    },
+    }},
     "creator_id": "100",
     "description": "description",
     "is_dirty": null,
     "name": "name",
-    "serialized_source_guild": {
+    "serialized_source_guild": {{
         "afk_channel_id": null,
         "afk_timeout": 300,
         "channels": [
-            {
+            {{
                 "bitrate": 64000,
                 "id": 1,
                 "name": "Text Channels",
@@ -86,34 +91,34 @@ mod tests {
                 "topic": null,
                 "type": 4,
                 "user_limit": 0
-            },
-            {
+            }},
+            {{
                 "bitrate": 64000,
                 "id": 2,
                 "name": "general",
                 "nsfw": false,
                 "parent_id": 1,
                 "permission_overwrites": [
-                    {
+                    {{
                         "allow": "0",
                         "deny": "2048",
                         "id": 1,
                         "type": 0
-                    },
-                    {
+                    }},
+                    {{
                         "allow": "2048",
                         "deny": "0",
                         "id": 2,
                         "type": 0
-                    }
+                    }}
                 ],
                 "position": 0,
                 "rate_limit_per_user": 0,
                 "topic": null,
                 "type": 0,
                 "user_limit": 0
-            },
-            {
+            }},
+            {{
                 "bitrate": 64000,
                 "id": 3,
                 "name": "Voice Channels",
@@ -125,8 +130,8 @@ mod tests {
                 "topic": null,
                 "type": 4,
                 "user_limit": 0
-            },
-            {
+            }},
+            {{
                 "bitrate": 64000,
                 "id": 4,
                 "name": "General",
@@ -138,7 +143,7 @@ mod tests {
                 "topic": null,
                 "type": 2,
                 "user_limit": 0
-            }
+            }}
         ],
         "default_message_notifications": 0,
         "description": null,
@@ -147,44 +152,47 @@ mod tests {
         "name": "server name",
         "preferred_locale": "en-US",
         "roles": [
-            {
+            {{
                 "color": 0,
                 "hoist": false,
                 "id": 200,
                 "mentionable": false,
                 "name": "@everyone",
                 "permissions": "104320577"
-            },
-            {
+            }},
+            {{
                 "color": 0,
                 "hoist": false,
                 "id": 1,
                 "mentionable": false,
                 "name": "new role",
                 "permissions": "104320577"
-            }
+            }}
         ],
         "system_channel_flags": 0,
         "system_channel_id": 2,
         "verification_level": 0
-    },
+    }},
     "source_guild_id": "200",
     "updated_at": "2021-04-07T14:55:37+00:00",
     "usage_count": 0
-}"#;
+}}"#,
+            avatar = image_hash::AVATAR_INPUT,
+            banner = image_hash::BANNER_INPUT
+        );
 
         let value = Template {
             code: "code".into(),
             created_at,
             creator: User {
                 accent_color: None,
-                avatar: Some("avatar".into()),
-                banner: Some("06c16474723fe537c283b8efa61a30c8".to_owned()),
+                avatar: Some(image_hash::AVATAR),
+                banner: Some(image_hash::BANNER),
                 bot: false,
                 email: None,
                 discriminator: 1111,
                 flags: None,
-                id: UserId::new(100).expect("non zero"),
+                id: Id::new(100),
                 locale: None,
                 mfa_enabled: None,
                 name: "username".into(),
@@ -193,7 +201,7 @@ mod tests {
                 system: None,
                 verified: None,
             },
-            creator_id: UserId::new(100).expect("non zero"),
+            creator_id: Id::new(100),
             description: Some("description".into()),
             is_dirty: None,
             name: "name".into(),
@@ -203,7 +211,7 @@ mod tests {
                 channels: vec![
                     GuildChannel::Category(CategoryChannel {
                         guild_id: None,
-                        id: ChannelId::new(1).expect("non zero"),
+                        id: Id::new(1),
                         kind: ChannelType::GuildCategory,
                         name: "Text Channels".into(),
                         permission_overwrites: vec![],
@@ -211,27 +219,23 @@ mod tests {
                     }),
                     GuildChannel::Text(TextChannel {
                         guild_id: None,
-                        id: ChannelId::new(2).expect("non zero"),
+                        id: Id::new(2),
                         kind: ChannelType::GuildText,
                         last_message_id: None,
                         last_pin_timestamp: None,
                         name: "general".into(),
                         nsfw: false,
-                        parent_id: Some(ChannelId::new(1).expect("non zero")),
+                        parent_id: Some(Id::new(1)),
                         permission_overwrites: vec![
                             PermissionOverwrite {
                                 allow: Permissions::from_bits(0).unwrap(),
                                 deny: Permissions::from_bits(2048).unwrap(),
-                                kind: PermissionOverwriteType::Role(
-                                    RoleId::new(1).expect("non zero"),
-                                ),
+                                kind: PermissionOverwriteType::Role(Id::new(1)),
                             },
                             PermissionOverwrite {
                                 allow: Permissions::from_bits(2048).unwrap(),
                                 deny: Permissions::from_bits(0).unwrap(),
-                                kind: PermissionOverwriteType::Role(
-                                    RoleId::new(2).expect("non zero"),
-                                ),
+                                kind: PermissionOverwriteType::Role(Id::new(2)),
                             },
                         ],
                         position: 0,
@@ -240,7 +244,7 @@ mod tests {
                     }),
                     GuildChannel::Category(CategoryChannel {
                         guild_id: None,
-                        id: ChannelId::new(3).expect("non zero"),
+                        id: Id::new(3),
                         kind: ChannelType::GuildCategory,
                         name: "Voice Channels".into(),
                         permission_overwrites: vec![],
@@ -249,10 +253,10 @@ mod tests {
                     GuildChannel::Voice(VoiceChannel {
                         bitrate: 64000,
                         guild_id: None,
-                        id: ChannelId::new(4).expect("non zero"),
+                        id: Id::new(4),
                         kind: ChannelType::GuildVoice,
                         name: "General".into(),
-                        parent_id: Some(ChannelId::new(3).expect("non zero")),
+                        parent_id: Some(Id::new(3)),
                         permission_overwrites: vec![],
                         rtc_region: None,
                         position: 0,
@@ -270,7 +274,7 @@ mod tests {
                     TemplateRole {
                         color: 0,
                         hoist: false,
-                        id: RoleId::new(200).expect("non zero"),
+                        id: Id::new(200),
                         mentionable: false,
                         name: "@everyone".into(),
                         permissions: Permissions::CREATE_INVITE
@@ -292,7 +296,7 @@ mod tests {
                     TemplateRole {
                         color: 0,
                         hoist: false,
-                        id: RoleId::new(1).expect("non zero"),
+                        id: Id::new(1),
                         mentionable: false,
                         name: "new role".into(),
                         permissions: Permissions::CREATE_INVITE
@@ -313,15 +317,15 @@ mod tests {
                     },
                 ],
                 system_channel_flags: SystemChannelFlags::empty(),
-                system_channel_id: Some(ChannelId::new(2).expect("non zero")),
+                system_channel_id: Some(Id::new(2)),
                 verification_level: VerificationLevel::None,
             },
-            source_guild_id: GuildId::new(200).expect("non zero"),
+            source_guild_id: Id::new(200),
             updated_at,
             usage_count: 0,
         };
 
-        let deserialized = serde_json::from_str::<Template>(raw).unwrap();
+        let deserialized = serde_json::from_str::<Template>(&raw).unwrap();
 
         assert_eq!(deserialized, value);
 
@@ -345,16 +349,16 @@ mod tests {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("avatar"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::Some,
-                Token::Str("06c16474723fe537c283b8efa61a30c8"),
+                Token::Str(image_hash::BANNER_INPUT),
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
                 Token::Str("1111"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("100"),
                 Token::Str("username"),
                 Token::Str("username"),
@@ -363,7 +367,7 @@ mod tests {
                 Token::U64(0),
                 Token::StructEnd,
                 Token::Str("creator_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("100"),
                 Token::Str("description"),
                 Token::Some,
@@ -388,7 +392,7 @@ mod tests {
                     len: 5,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("type"),
                 Token::U8(4),
@@ -405,7 +409,7 @@ mod tests {
                     len: 8,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(0),
@@ -415,7 +419,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("parent_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("permission_overwrites"),
                 Token::Seq { len: Some(2) },
@@ -457,7 +461,7 @@ mod tests {
                     len: 5,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("type"),
                 Token::U8(4),
@@ -476,7 +480,7 @@ mod tests {
                 Token::Str("bitrate"),
                 Token::U64(64000),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::Str("type"),
                 Token::U8(2),
@@ -484,7 +488,7 @@ mod tests {
                 Token::Str("General"),
                 Token::Str("parent_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("permission_overwrites"),
                 Token::Seq { len: Some(0) },
@@ -519,7 +523,7 @@ mod tests {
                 Token::Str("hoist"),
                 Token::Bool(false),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("200"),
                 Token::Str("mentionable"),
                 Token::Bool(false),
@@ -537,7 +541,7 @@ mod tests {
                 Token::Str("hoist"),
                 Token::Bool(false),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "RoleId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("mentionable"),
                 Token::Bool(false),
@@ -551,13 +555,13 @@ mod tests {
                 Token::U64(0),
                 Token::Str("system_channel_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("verification_level"),
                 Token::U8(0),
                 Token::StructEnd,
                 Token::Str("source_guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("200"),
                 Token::Str("updated_at"),
                 Token::Str("2021-04-07T14:55:37.000000+00:00"),
