@@ -1,5 +1,8 @@
 use super::{DiscriminatorDisplay, PremiumType, UserFlags};
-use crate::id::UserId;
+use crate::{
+    id::{marker::UserMarker, Id},
+    util::image_hash::ImageHash,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
@@ -8,9 +11,9 @@ pub struct UserProfile {
     ///
     /// This is an integer representation of a hexadecimal color code.
     pub accent_color: Option<u64>,
-    pub avatar: Option<String>,
+    pub avatar: Option<ImageHash>,
     /// Hash of the user's banner image.
-    pub banner: Option<String>,
+    pub banner: Option<ImageHash>,
     #[serde(default)]
     pub bot: bool,
     /// Discriminator used to differentiate people with the same username.
@@ -26,7 +29,7 @@ pub struct UserProfile {
     pub email: Option<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub flags: Option<UserFlags>,
-    pub id: UserId,
+    pub id: Id<UserMarker>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub locale: Option<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -50,7 +53,8 @@ impl UserProfile {
 
 #[cfg(test)]
 mod tests {
-    use super::{PremiumType, UserFlags, UserId, UserProfile};
+    use super::{PremiumType, UserFlags, UserProfile};
+    use crate::{id::Id, test::image_hash};
     use serde_test::Token;
 
     fn user_tokens(discriminator_token: Token) -> Vec<Token> {
@@ -64,7 +68,7 @@ mod tests {
             Token::U64(16_579_836),
             Token::Str("avatar"),
             Token::Some,
-            Token::Str("hash"),
+            Token::Str(image_hash::AVATAR_INPUT),
             Token::Str("banner"),
             Token::None,
             Token::Str("bot"),
@@ -78,7 +82,7 @@ mod tests {
             Token::Some,
             Token::U64(131_072),
             Token::Str("id"),
-            Token::NewtypeStruct { name: "UserId" },
+            Token::NewtypeStruct { name: "Id" },
             Token::Str("1"),
             Token::Str("locale"),
             Token::Some,
@@ -102,13 +106,13 @@ mod tests {
     fn test_user_profile() {
         let value = UserProfile {
             accent_color: Some(16_579_836),
-            avatar: Some("hash".to_owned()),
+            avatar: Some(image_hash::AVATAR),
             banner: None,
             bot: false,
             discriminator: 4,
             email: Some("email@example.com".to_owned()),
             flags: Some(UserFlags::VERIFIED_DEVELOPER),
-            id: UserId::new(1).expect("non zero"),
+            id: Id::new(1),
             locale: Some("en-us".to_owned()),
             mfa_enabled: Some(true),
             name: "user name".to_owned(),
